@@ -274,20 +274,13 @@ sub readUserTrackingData
 
 	foreach my $utdata ($doc->findnodes('/UTDetails/UTData'))
 	{
-
-#my $testMac = trim($utdata->findnodes('./MACAddress')->string_value);
-#my $test = 0;
-#if ($testMac eq '00-13-21-6a-c3-2b') { $test = 1 };
-#if ($testMac eq '00-24-e8-36-1a-40') { $test = 1 };
-#if ($test) { print ">>>> 00-24-e8-36-1a-40 found <<<<\n"; }
-#if ($test) { print $utdata->toString(); }
 		# check netwerk op basis van VTPDomain
 		my $vtpDomain = trim($utdata->findnodes('./VTPDomain')->string_value);
 
 		my $network = "unknown";
 		if ($vtpDomain =~ m/^KUB*/) { $network = "UvT"; }
 		if ($vtpDomain =~ m/^Breeburg*/) { $network = "WMB"; }
-#if ($test) { print "network = $network\n"; }
+
 		# als het netwerk nog niet bestaat in de tracking data structure -> toevoegen
 		unless ($trackingData->hasNetwork($network))
 		{
@@ -299,9 +292,10 @@ sub readUserTrackingData
 		# hiervoor deze fix :
         my $cwVlan = trim($utdata->findnodes('./VLAN')->string_value);
 		my $cwVlanId = trim($utdata->findnodes('./VLANId')->string_value);
-#if ($test) { if ($cwVlan =~ /^\d+$/) { print "vlan is numeric : $cwVlan\n" } else { print "vlan not numeric : $cwVlan\n"; } }
+
 		my $vlan = $cwVlan =~ /^\d+$/ ? $cwVlan : $cwVlanId;
-#if ($test) { print "vlan = $vlan\n";}
+
+
 		# als het vlan niet bestaat in het betreffende netwerk object -> toevoegen
 		unless ($trackingData->getNetworkByName($network)->hasVlan($vlan))
 		{
@@ -309,14 +303,9 @@ sub readUserTrackingData
 			$trackingData->getNetworkByName($network)->addVlan($newVlan);
 		}
 
-#if ($test) { print ">>>> 00-24-e8-36-1a-40 still 1 found <<<<\n"; }
-
-
 		my $mac = trim($utdata->findnodes('./MACAddress')->string_value);
 		$mac =~ s/[^a-zA-Z0-9 ]//g;
 
-#if ($test) { print ">>>> 00-24-e8-36-1a-40 still 2 found <<<<\n"; }
-
 		# als het mac address niet bestaat in het betreffende vlan object -> toevoegen
 		unless ($trackingData->getNetworkByName($network)->getVlanById($vlan)->hasMacAddress($mac))
 		{
@@ -324,7 +313,6 @@ sub readUserTrackingData
 			$trackingData->getNetworkByName($network)->getVlanById($vlan)->addMacAddress($newMac);	
 		}
 
-
 		# op dit punt bestaat het betreffende mac adres in de het trackingData object -> TrackingData hieraan toevoegen
 		my $switchIp = trim($utdata->findnodes('./Device')->string_value);
 		my $switchPort = trim($utdata->findnodes('./Port')->string_value);
@@ -420,31 +408,46 @@ sub readIntreg
 # Return : (1x)
 #       1) een object van het type UvTRegList :
 #
-#        bless( {
-#                 'registrations' => {
-#                                      '00-26-6C-85-F2-AD' => bless( {
-#                                                                      'regDate' => '1-2-2012',
-#                                                                      'vlanName' => 'UvT-studenten',
-#                                                                      'number' => '38 21',
-#                                                                      'street' => 'V Doorenstr',
-#                                                                      'name' => 'Albers',
-#                                                                      'mac' => '00266c85f2ad'
-#                                                                    }, 'UvT::NOC::MacRegistration::WMBRegistration' ),
-#                                      '00-24-BE-05-12-28' => bless( {
-#                                                                      'regDate' => '14-3-2013',
-#                                                                      'vlanName' => 'UvT-studenten',
-#                                                                      'number' => '37 01',
-#                                                                      'street' => 'Daltonerf',
-#                                                                      'name' => 'Jong',
-#                                                                      'mac' => '0024be051228'
-#                                                                    }, 'UvT::NOC::MacRegistration::WMBRegistration' )
-#                                    }
+#		bless( {
+#                 'addresses' => {
+#                                  'V Doorenstr 38 21' => bless( {
+#                                                                  'number' => '38 21',
+#                                                                  'street' => 'V Doorenstr',
+#                                                                  'registrations' => {
+#                                                                                       'Figaroa-00-16-0A-22-3E-95--13-3-2013-niet-UvT-studenten' => bless( {
+#                                                                                                                                                             'regDate' => '13-3-2013',
+#                                                                                                                                                             'mac1' => '00-16-0A-22-3E-95',
+#                                                                                                                                                             'vlanName' => 'niet-UvT-studenten',
+#                                                                                                                                                             'mac2' => '',
+#                                                                                                                                                             'name' => 'Figaroa'
+#                                                                                                                                                           }, #'UvT::NOC::MacRegistration::WMBRegistration' ),
+#                                                                                       'Albers-64-D1-A3-0D-7A-DF--27-11-2013-UvT-studenten' => bless( {
+#                                                                                                                                                        'regDate' => '27-11-2013',
+#                                                                                                                                                        'mac1' => '64-D1-A3-0D-7A-DF',
+#                                                                                                                                                        'vlanName' => 'UvT-studenten',
+#                                                                                                                                                        'mac2' => '',
+#                                                                                                                                                        'name' => 'Albers'
+#                                                                                                                                                      }, #'UvT::NOC::MacRegistration::WMBRegistration' )
+#                                                                                     }
+#                                                                }, 'UvT::NOC::MacRegistration::WMBAddress' ),
+#                                  'Daltonerf 37 01' => bless( {
+#                                                                'number' => '37 01',
+#                                                                'street' => 'Daltonerf',
+#                                                                'registrations' => {
+#                                                                                     'Jong-00-A0-C9-42-FD-95---UvT-studenten' => bless( {
+#                                                                                                                                          'regDate' => '',
+#                                                                                                                                          'mac1' => '00-A0-C9-42-FD-95',
+#                                                                                                                                          'vlanName' => 'UvT-studenten',
+#                                                                                                                                          'mac2' => '',
+#                                                                                                                                          'name' => 'Jong'
+#                                                                                                                                        }, 'UvT::NOC::MacRegistration::WMBRegistration' )
+#                                                                                   }
+#                                                              }, 'UvT::NOC::MacRegistration::WMBAddress' )
+#                                }
 #               }, 'UvT::NOC::MacRegistration::WMBRegList' );
 #
-#
 # Omschrijving :
-#       Functie om hosts file uit te lezen en de koppeling ip-adres op te slaan als
-#       object Host in het object HostList welke wordt geretourneerd
+#       Functie om de WMB registratie file uit te lezen en op te slaan in de datastructure WMBRegList welke wordt geretourneerd
 
 sub readWMBReg
 {
@@ -455,19 +458,21 @@ sub readWMBReg
 	my $regList = new UvT::NOC::MacRegistration::WMBRegList();
 
 	foreach my $line (split('\n', $data))
-    {
+	{
 		# De regel moet bestaan uit 8 velden gescheiden met een '|' (dus 7x '|')
 		if ($line =~ /([^|]*\|){7}/)
 		{
 			my @data = split(/\|/, trim($line));
-			my $mac = trim($data[3]);				$mac =~ s/[^a-zA-Z0-9 ]//g;
+			my $mac1 = trim($data[3]);				$mac1 =~ s/[^a-zA-Z0-9 ]//g;
+			my $mac2 = trim($data[4]);				$mac2 =~ s/[^a-zA-Z0-9 ]//g;
 			my $name = trim($data[0]);
 			my $street = trim($data[5]);
 			my $number = trim($data[6]);
 			my $regDate = trim($data[1]);
 			my $vlanName = trim($data[7]);
 
-			$regList->addRegistration(new UvT::NOC::MacRegistration::WMBRegistration(lc($mac), $name, $street, $number, $regDate, $vlanName));
+			#$regList->addRegistration(new UvT::NOC::MacRegistration::WMBRegistration(lc($mac1), lc($mac2), $name, $street, $number, $regDate, $vlanName));
+			$regList->addRegistration($street, $number, $name, $mac1, $mac2, $regDate, $vlanName);
 		}
 	}
 
